@@ -19,7 +19,7 @@ __project__ = "logfile"
 __author__ = u"Sébastien Boisgérault <Sebastien.Boisgerault@mines-paristech.fr>"
 __license__ = "MIT License"
 __url__     = "https://github.com/boisgera/logfile"
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 __classifiers__ = """
 Intended Audience :: Developers
 Operating System :: OS Independent
@@ -101,6 +101,12 @@ Topic :: System :: Logging
 #       kind of redundant ?). Yes, but only in logfile.warning calls, restore
 #       the filter state after that. Implement pre-post hooks as context
 #       managers ?
+#       ABOUT WARNINGS: logfile should probably NOT integrate warnings,
+#       because some features would be redundant (filters, print to
+#       stdout, etc.). The ability to turn warnings into errors could
+#       be easily programmed in each module that needs it, and controlled
+#       by a global function (think of `seterr` in `numpy`). No need to
+#       offer that in logfile ...
 
 # TODO: implement the full local / global / builtin namespaces in templating.
 
@@ -239,7 +245,7 @@ class LogFile(int):
             if module is not None:
                 module_name = module.__name__
                 if module_name == "__main__":
-                    app_name = getattr(module, "__project__")
+                    app_name = getattr(module, "__project__", None)
                     if app_name:
                         tag_parts.append(app_name)
                 else:
